@@ -10,7 +10,7 @@ from . import scripts
 __title__ = 'python_plus'
 __author__ = 'Antonio Maria Vigliotti'
 __copyright__ = 'Copyright 2018-2025 SHS-AV srl'
-__version__ = '2.0.16'
+__version__ = '2.0.17'
 
 PYCODESET = 'utf-8'
 if PY3:
@@ -267,25 +267,25 @@ def compute_date(value, refdate=None):
     return value
 
 
-class Base__(type):
-    def __instancecheck__(cls, instance):
-        if cls == __:
-            return isinstance(instance, text_type)
-        else:
-            return issubclass(instance.__class__, cls)
-
-
-class __(object, with_metaclass(Base__, text_type)):
-    def qsplit(
-        self, sep=None, maxsplit=-1, quotes=None, escape=None, enquote=None, strip=None
-    ):
-        return qsplit(
-            self,
-            sep=sep,
-            maxsplit=maxsplit,
-            quotes=quotes,
-            escape=escape,
-            enquote=enquote,
-            strip=strip,
-        )
+# class Base__(type):
+#     def __instancecheck__(cls, instance):
+#         if cls == __:
+#             return isinstance(instance, text_type)
+#         else:
+#             return issubclass(instance.__class__, cls)
+#
+#
+# class __(object, with_metaclass(Base__, text_type)):
+#     def qsplit(
+#         self, sep=None, maxsplit=-1, quotes=None, escape=None, enquote=None, strip=None
+#     ):
+#         return qsplit(
+#             self,
+#             sep=sep,
+#             maxsplit=maxsplit,
+#             quotes=quotes,
+#             escape=escape,
+#             enquote=enquote,
+#             strip=strip,
+#         )
 
